@@ -26,29 +26,28 @@ class GraphqlClient(object):
     def request(self, query, params, token=None):
         # type:(str,dict,str) -> any
         headers = {
-            'x-authing-sdk-version': 'python:%s' % __version__,
-            'x-authing-userpool-id': self.options.user_pool_id if hasattr(self.options, 'user_pool_id') else None,
-            'x-authing-request-from': 'sdk',
-            'x-authing-app-id': self.options.app_id if hasattr(self.options, 'app_id') else None,
+            "x-authing-sdk-version": "python:%s" % __version__,
+            "x-authing-userpool-id": self.options.user_pool_id
+            if hasattr(self.options, "user_pool_id")
+            else None,
+            "x-authing-request-from": "sdk",
+            "x-authing-app-id": self.options.app_id
+            if hasattr(self.options, "app_id")
+            else None,
         }
         if token:
-            headers['authorization'] = 'Bearer %s' % token
+            headers["authorization"] = "Bearer %s" % token
         transport = RequestsHTTPTransport(self.endpoint, headers=headers)
-        client = Client(transport=transport,
-                        fetch_schema_from_transport=True)
+        client = Client(transport=transport, fetch_schema_from_transport=True)
 
-        result = client.execute(
-            gql(query), variable_values=params)
+        result = client.execute(gql(query), variable_values=params)
         if result.errors:
             print(result.errors)
             errmsg = None
             errcode = None
             for _, err in enumerate(result.errors):
-                msg = err['message']
-                errcode, errmsg = msg['code'], msg['message']
+                msg = err["message"]
+                errcode, errmsg = msg["code"], msg["message"]
                 self.options.on_error(errcode, errmsg)
-            raise AuthingException(
-                code=errcode,
-                errmsg=errmsg
-            )
+            raise AuthingException(code=errcode, errmsg=errmsg)
         return result.data
