@@ -2,10 +2,7 @@ from ..exceptions import AuthingException
 
 
 def DEFAULT_ONERROR(code, message):
-    raise AuthingException(
-        code=code,
-        errmsg=message
-    )
+    raise AuthingException(code=code, errmsg=message)
 
 
 DEFAULT_ENCRYPT_PUBLICKEY = """
@@ -18,13 +15,21 @@ GKl64GDcIq3au+aqJQIDAQAB
 """
 
 
-class ManagementClientOptions():
-    def __init__(self, user_pool_id, secret, host=None, enc_public_key=None, on_error=None, timeout=10.0):
+class ManagementClientOptions:
+    def __init__(
+        self,
+        user_pool_id,
+        secret,
+        host=None,
+        enc_public_key=None,
+        on_error=None,
+        timeout=10.0,
+    ):
         # type:(str,str,str,str,any,float) -> ManagementClientOptions
         self.user_pool_id = user_pool_id
         self.secret = secret
-        self.host = host or 'https://core.authing.cn'
+        self.host = host or "https://core.authing.cn"
         self.on_error = on_error or DEFAULT_ONERROR
         self.timeout = timeout
-        self.graphql_endpoint = '%s/graphql/v2' % self.host
+        self.graphql_endpoint = "%s/graphql/v2" % self.host
         self.enc_public_key = enc_public_key or DEFAULT_ENCRYPT_PUBLICKEY
